<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Administration\Controller;

use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\Routing\Annotation\RouteScope;
use Shopware\Core\Framework\Routing\Exception\MissingRequestParameterException;
use Shopware\Core\Framework\Validation\DataBag\RequestDataBag;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Routing\Annotation\Route;
use Mefi\Inkasso\Components\Claim\ClaimStatusHistoryServiceInterface;
use Mefi\Inkasso\Components\ConfigReader\ConfigReaderInterface;
use Mefi\Inkasso\Components\ConfigReader\Struct\Configuration;
use Mefi\Inkasso\Components\Partner\PartnerRegistrationServiceInterface;
use Mefi\Inkasso\Utils\Connection\ConnectionValidatorInterface;

/**
 * @RouteScope(scopes={"api"})
 */
class MediafinanzConfigController extends AbstractController
{
    /** @var ConnectionValidatorInterface */
    private $connectionValidator;

    /** @var ConfigReaderInterface */
    private $configReader;

    /** @var PartnerRegistrationServiceInterface */
    private $partnerRegistrationService;

    /** @var ClaimStatusHistoryServiceInterface */
    private $claimStatusHistoryService;

    public function __construct(
        ConnectionValidatorInterface $connectionValidator,
        ConfigReaderInterface $configReader,
        PartnerRegistrationServiceInterface $partnerRegistrationService,
        ClaimStatusHistoryServiceInterface $claimStatusHistoryService
    ) {
        $this->connectionValidator        = $connectionValidator;
        $this->configReader               = $configReader;
        $this->partnerRegistrationService = $partnerRegistrationService;
        $this->claimStatusHistoryService  = $claimStatusHistoryService;
    }

    /**
     * @Route("/api/_action/mediafinanz-config/test-connection", name="api.action.mefi.inkasso.config.test", methods={"POST"})
     */
    public function testConnection(RequestDataBag $request): JsonResponse
    {
        $clientId      = $request->get('clientId');
        $clientLicence = $request->get('clientLicence');

        if (empty($clientId)) {
            throw new MissingRequestParameterException('clientId');
        }

        if (empty($clientLicence)) {
            throw new MissingRequestParameterException('licenceKey');
        }

        $validationResult = $this->connectionValidator->testConnection($clientId, $clientLicence);
        // @todo modal dialog "Forderungsabgleich ja/nein"
        // anschließend ClaimList verarbeiten
         /*if ($validationResult->getClaimList()) {
            error_log(date('Y-m-d H:i:s') . "\tfirst invoice number: " . var_export($validationResult->getClaimList()[0]->getInvoice()->getInvoiceNumber(), true) . "\n", 3, '/app/var/log/soap.log');
        }*/
        return new JsonResponse($validationResult->jsonSerialize());
    }

    /**
     * @Route("/api/_action/mediafinanz-config/client-registered", name="api.action.mefi.inkasso.config.client.registered", methods={"GET"})
     */
    public function isClientRegistered(): JsonResponse
    {
        return new JsonResponse([
            'isClientRegistered' => $this->configReader->read()->get(Configuration::CONFIG_CLIENT_REGISTERED, false),
        ]);
    }

    /**
     * @Route("/api/_action/mediafinanz-config/register", name="api.action.mefi.inkasso.config.register", methods={"POST"})
     */
    public function register(RequestDataBag $request): JsonResponse
    {
        $response = $this->partnerRegistrationService->registerClient($request);

        return new JsonResponse($response);
    }

    /**
     * @Route("/api/_action/mediafinanz-config/generate-registration-key", name="api.action.mefi.inkasso.config.generate-registration-key", methods={"POST"})
     */
    public function generateRegistrationKey(): JsonResponse
    {
        $response = $this->partnerRegistrationService->generateRegistrationKey();

        return new JsonResponse($response->jsonSerialize());
    }

    /**
     * @Route("/api/_action/mediafinanz-config/sync-claim-status-changes", name="api.action.mefi.inkasso.config.sync_claim_status_changes", methods={"POST"})
     */
    public function syncClaimStatusChanges(Context $context): JsonResponse
    {
        $result = $this->claimStatusHistoryService->fetchClaimStatusChanges($context);

        return new JsonResponse($result->jsonSerialize());
    }
}
