<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Claim\Hydrator;

use DateTime;
use Shopware\Core\Framework\Validation\DataBag\RequestDataBag;
use Mefi\Inkasso\Components\Claim\Struct\NewClaimFormStruct;

class NewClaimFormHydrator implements NewClaimFormHydratorInterface
{
    public function hydrate(RequestDataBag $request): NewClaimFormStruct
    {
        $claimCustomer         = $request->get('claimCustomer');
        $claimDetail           = $request->get('claimDetail');
        $defaultBillingAddress = $claimCustomer->get('defaultBillingAddress');
        $country               = $defaultBillingAddress->get('country');
        $order                 = $request->get('order');

        $orderDateTime = strtotime($order->get('orderDate'));

        $orderDate = new DateTime();
        $orderDate->setTimestamp($orderDateTime);

        $claimForm = new NewClaimFormStruct();
        $claimForm->setCustomerId((string) $request->get('customerId'));
        $claimForm->setOrderId((string) $request->get('orderId'));
        $claimForm->setStreet((string) $claimCustomer->get('street'));
        $claimForm->setEmail((string) $claimCustomer->get('email'));
        $claimForm->setLastName((string) $claimCustomer->get('lastName'));
        $claimForm->setFirstName((string) $claimCustomer->get('firstName'));
        $claimForm->setCountry((string) $country->get('iso'));
        $claimForm->setCountryId((string) $country->get('id'));
        $claimForm->setCompany((string) $claimCustomer->get('company'));
        $claimForm->setCity((string) $claimCustomer->get('city'));
        $claimForm->setClaimAmount((float) $claimDetail->get('amount'));
        $claimForm->setClaimDate(new DateTime());
        $claimForm->setClaimFee((float) $claimDetail->get('cost'));
        $claimForm->setClaimType((int) $claimDetail->get('type'));
        $claimForm->setClaimReason((string) $claimDetail->get('reason'));
        $claimForm->setNote((string) $claimDetail->get('notice'));
        $claimForm->setInvoiceNumber($request->get('invoiceNumber'));
        $claimForm->setOrderDate($orderDate);
        $claimForm->setPhone((string) $defaultBillingAddress->get('phoneNumber'));
        $claimForm->setZipCode((string) $claimCustomer->get('zipCode'));
        $claimForm->setDateOfLastReminder((string) $claimDetail->get('dateOfLastReminder'));

        return $claimForm;
    }
}
