<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\ConfigReader;

use Shopware\Core\System\SystemConfig\SystemConfigService;
use Mefi\Inkasso\Components\ConfigReader\Struct\Configuration;


class ConfigReader implements ConfigReaderInterface
{
    /** @var SystemConfigService */
    private $systemConfigService;

    /** @var Configuration[] */
    private $configurations = [];

    /** @var array */
    private $envData;

    public function __construct(
        SystemConfigService $systemConfigService,
        string $kernelEnv,
        array $envData
    ) {
        $this->systemConfigService = $systemConfigService;
        $this->envData             = $this->finalizeEnvData($envData, $kernelEnv);
    }

    public function read(?string $salesChannelId = null, bool $inherit = true): Configuration
    {
        $cacheKey = $salesChannelId ?? 'default';

        if (array_key_exists($cacheKey, $this->configurations)) {
            return $this->configurations[$cacheKey];
        }

        $values = $this->systemConfigService->getDomain(
            ConfigReaderInterface::SYSTEM_CONFIG_DOMAIN,
            $salesChannelId,
            $inherit
        );

        $config = [];
        foreach ($values as $key => $value) {
            $property = substr($key, strlen(ConfigReaderInterface::SYSTEM_CONFIG_DOMAIN));

            $config[$property] = $value;
        }

        $config = array_merge($config, $this->envData);

        $this->configurations[$cacheKey] = new Configuration($config);

        return $this->configurations[$cacheKey];
    }

    private function finalizeEnvData(array $envData, string $kernelEnv): array
    {
        if (array_key_exists(Configuration::CONFIG_SANDBOX_ACTIVE, $envData)
            && empty($envData[Configuration::CONFIG_SANDBOX_ACTIVE]) && $kernelEnv === 'dev') {
            $envData[Configuration::CONFIG_SANDBOX_ACTIVE] = true;
        }

        if (array_key_exists(Configuration::CONFIG_SANDBOX_ACTIVE, $envData)) {
            $envData[Configuration::CONFIG_SANDBOX_ACTIVE] = filter_var($envData[Configuration::CONFIG_SANDBOX_ACTIVE], FILTER_VALIDATE_BOOLEAN);
        }

        if (array_key_exists(Configuration::CONFIG_CLIENT_REGISTERED, $envData)) {
            $envData[Configuration::CONFIG_CLIENT_REGISTERED] = filter_var($envData[Configuration::CONFIG_CLIENT_REGISTERED], FILTER_VALIDATE_BOOLEAN);
        }

        if (!array_key_exists(Configuration::CONFIG_APPLICATION_LICENCE, $envData) || empty($envData[Configuration::CONFIG_APPLICATION_LICENCE])) {
            $envData[Configuration::CONFIG_APPLICATION_LICENCE] = Configuration::DEFAULT_APPLICATION_LICENSE;
        }

        return $envData;
    }
}
