<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI\Buergel\Request\Builder\Hydrator;

use Shopware\Core\Checkout\Order\Aggregate\OrderAddress\OrderAddressEntity;
use Mefi\Inkasso\Components\SoapAPI\Buergel\DataTypes\BuergelSuspect;
use VIISON\AddressSplitter\AddressSplitter;
use VIISON\AddressSplitter\Exceptions\SplittingException;

class BuergelSuspectHydrator implements BuergelSuspectHydratorInterface
{
    public function hydrate(OrderAddressEntity $orderAddress, string $customerEmail): BuergelSuspect
    {
        $buergelSuspect = new BuergelSuspect();
        $buergelSuspect->setCity($orderAddress->getCity());
        $buergelSuspect->setCompany($orderAddress->getCompany());
       // $buergelSuspect->setEmailAddress($customerEmail);
        $buergelSuspect->setPostcode($orderAddress->getZipcode());
      //  $buergelSuspect->setPhonenumber($orderAddress->getPhoneNumber());
        $buergelSuspect->setFirstname($orderAddress->getFirstName());
        $buergelSuspect->setLastname($orderAddress->getLastName());
        $buergelSuspect->setRegisterEntry($orderAddress->getVatId());

        try {
            $street      = AddressSplitter::splitAddress($orderAddress->getStreet());
            $houseNumber = array_key_exists('houseNumber', $street) && !empty($street['houseNumber']) ? $street['houseNumber'] : null;
            $streetName  = array_key_exists('streetName', $street) && !empty($street['streetName']) ? $street['streetName'] : null;

            $buergelSuspect->setHouseNumber($houseNumber);
            $buergelSuspect->setStreet($streetName);
        } catch (SplittingException $ex) {
            $buergelSuspect->setStreet($orderAddress->getStreet());
        }

        return $buergelSuspect;
    }
}
