<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI\DataTypes;

use Shopware\Core\Framework\Struct\Struct;

class Error extends Struct
{
    /** @var null|string */
    protected $code;

    /** @var string */
    protected $message;

    /** @var string */
    protected $raw;

    public function __construct(string $error)
    {
        $this->raw     = $error;
        $this->code    = $this->getErrorCodeFromError($error);
        $this->message = $this->getErrorMessageFromError($error);
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function getMessage(): string
    {
        return $this->message;
    }

    public function getRaw(): string
    {
        return $this->raw;
    }

    private function getErrorCodeFromError(string $error): ?string
    {
        if ($error[9] !== ':') {
            return null;
        }

        //The first 8 bytes are the code in HEX starting at 0x00000000 and increasing to 0xFFFFFFFF
        return substr($error, 0, 8);
    }

    private function getErrorMessageFromError(string $error): string
    {
        if ($error[9] !== ':') {
            return $error;
        }

        return substr($error, 10);
    }
}
