<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI\Encashment\DataTypes;

use Shopware\Core\Framework\Struct\Struct;

class Claim extends Struct
{
    public const CATALOG_REASONS = [
        40100 => 'Newspaper notice(s)',
        40101 => 'Medical service',
        40102 => 'Consulting',
        40103 => 'Service',
        40104 => 'IT service/web design',
        40105 => 'Increased transport fee',
        40106 => 'Freight costs',
        40107 => 'Business activity provided by self-employed person',
        40108 => 'Tradesperson service',
        40109 => 'Hotel costs',
        40110 => 'Daycare centre contribution/dinner money',
        40111 => 'Patient transport costs',
        40112 => 'Course/teaching costs',
        40113 => 'Broker’s commission',
        40114 => 'Rent',
        40115 => 'Membership',
        40117 => "Lawyer's fee",
        40118 => 'Travel service',
        40119 => 'Repair service',
        40120 => 'Server rental',
        40121 => 'Tax advisor’s fee',
        40122 => 'Transport costs',
        40123 => 'Telecommunications services',
        40124 => 'Veterinary service',
        40126 => 'Teaching costs',
        40127 => 'Agency activities',
        40128 => 'Goods delivery(ies)',
        40129 => 'Goods delivery on prepayment basis',
        40130 => 'Web hosting',
        40131 => 'Other claim',
        40132 => 'Dentistry service',
    ];

    /** @var string */
    protected $invoice;

    /** @var int */
    protected $type;

    /** @var string */
    protected $reason;

    /** @var float */
    protected $originalValue;

    /** @var float */
    protected $overdueFees;

    /** @var float */
    protected $returnDebitNoteFees;

    /** @var string */
    protected $dateOfOrigin;

    /** @var string */
    protected $dateOfLastReminder;

    /** @var string */
    protected $note;

    /** @var int */
    protected $profile;

    /** @var string */
    protected $contractDate;

    /** @var string */
    protected $originalCreator;

    /** @var int */
    protected $catalogReason;

    /** @var string */
    protected $catalogText;

    public function getInvoice(): string
    {
        return $this->invoice;
    }

    public function getType(): int
    {
        return $this->type;
    }

    public function getReason(): string
    {
        return $this->reason;
    }

    public function getOriginalValue(): float
    {
        return $this->originalValue;
    }

    public function getOverdueFees(): float
    {
        return $this->overdueFees;
    }

    public function getReturnDebitNoteFees(): float
    {
        return $this->returnDebitNoteFees;
    }

    public function getDateOfOrigin(): string
    {
        return $this->dateOfOrigin;
    }

    public function getDateOfLastReminder(): string
    {
        return $this->dateOfLastReminder;
    }

    public function getNote(): string
    {
        return $this->note;
    }

    public function getProfile(): int
    {
        return $this->profile;
    }


    public function getContractDate(): string
    {
        return $this->contractDate;
    }

    public function getOriginalCreator(): string
    {
        return $this->originalCreator;
    }

    public function getCatalogReason(): int
    {
        return $this->catalogReason;
    }

    public function getCatalogText(): string
    {
        return $this->catalogText;
    }

    public function setInvoice(string $invoice): void
    {
        $this->invoice = $invoice;
    }

    public function setType(int $type): void
    {
        $this->type = $type;
    }

    public function setReason(string $reason): void
    {
        $this->reason = $reason;
    }

    public function setOriginalValue(float $originalValue): void
    {
        $this->originalValue = round($originalValue, 2);
    }

    public function setOverdueFees(float $overdueFees): void
    {
        $this->overdueFees = $overdueFees;
    }

    public function setReturnDebitNoteFees(float $returnDebitNoteFees): void
    {
        $this->returnDebitNoteFees = $returnDebitNoteFees;
    }

    public function setDateOfOrigin(string $dateOfOrigin): void
    {
        if ($dateOfOrigin === '') {
            $this->dateOfOrigin = $dateOfOrigin;

            return;
        }
        $time               = (int) strtotime($dateOfOrigin);
        $dateOfOrigin       = date('Y-m-d', $time);
        $this->dateOfOrigin = $dateOfOrigin;
    }

    public function setDateOfLastReminder(string $dateOfLastReminder): void
    {
        if ($dateOfLastReminder === '') {
            $time                     = strtotime('-7 days');
            $this->dateOfLastReminder = date('Y-m-d', $time);

            return;
        }
        $time                     = (int) strtotime($dateOfLastReminder);
        $dateOfLastReminder       = date('Y-m-d', $time);
        $this->dateOfLastReminder = $dateOfLastReminder;
    }

    public function setNote(string $note): void
    {
        $this->note = $note;
    }

    public function setProfile(int $profile): void
    {
        $this->profile = $profile;
    }


    public function setContractDate(string $contractDate): void
    {
        if ($contractDate === '') {
            $this->contractDate = $contractDate;

            return;
        }
        $time               = (int) strtotime($contractDate);
        $contractDate       = date('Y-m-d', $time);
        $this->contractDate = $contractDate;
    }

    public function setOriginalCreator(string $originalCreator): void
    {
        $this->originalCreator = $originalCreator;
    }

    public function setCatalogReason(int $catalogReason): void
    {
        if (!isset(self::CATALOG_REASONS[$catalogReason])) {
            return;
        }

        $this->catalogReason = $catalogReason;
    }

    public function setCatalogText(string $catalogText): void
    {
        $this->catalogText = $catalogText;
    }
}
