<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI\Encashment\Request\Builder;

use Shopware\Core\Framework\Context;
use Mefi\Inkasso\Components\Claim\Struct\NewClaimFormStruct;
use Mefi\Inkasso\Components\SoapAPI\Encashment\DataTypes\Claim;
use Mefi\Inkasso\Components\SoapAPI\Encashment\DataTypes\Debtor;
use Mefi\Inkasso\Components\SoapAPI\Encashment\Request\Struct\ClaimRequestStruct;

class NewClaimRequestBuilder implements NewClaimRequestBuilderInterface
{
    public function getData(NewClaimFormStruct $form, Context $context): ClaimRequestStruct
    {
        $claimRequestStruct = new ClaimRequestStruct();

        $claim  = $this->getClaim($form);
        $debtor = $this->getDebtor($form);

        $claimRequestStruct->setClaim($claim);
        $claimRequestStruct->setDebtor($debtor);

        return $claimRequestStruct;
    }

    private function getDebtor(NewClaimFormStruct $form): Debtor
    {
        $debtor = new Debtor();
        $debtor->setCity($form->getCity());
        $debtor->setAddress('@');
        $debtor->setCompany($form->getCompany());
        $debtor->setCountry($form->getCountry());
        $debtor->setEmail($form->getEmail());
        $debtor->setFirstname($form->getFirstName());
        $debtor->setLastname($form->getLastName());
        $debtor->setPostcode(substr($form->getZipCode(), 0, 5));
        $debtor->setStreet($form->getStreet());
        $debtor->setTelephone1($form->getPhone());

        return $debtor;
    }

    private function getClaim(NewClaimFormStruct $form): Claim
    {
        $claim = new Claim();

        $orderDateTime = $form->getOrderDate();

        if (!empty($form->getInvoiceNumber())) {
            $claim->setInvoice($form->getInvoiceNumber());
        }
        $claim->setType($form->getClaimType());
        $claim->setReason($form->getClaimReason());
        $claim->setOriginalValue($form->getClaimAmount());
        $claim->setOverdueFees($form->getClaimFee());
        $claim->setDateOfOrigin($orderDateTime->format('Y-m-d'));
        $claim->setDateOfLastReminder($form->getDateOfLastReminder());
        $claim->setNote($form->getNote());


        if ($form->getCompany()) {
            $claim->setOriginalCreator($form->getCompany());
        }

        $catalogReason = $this->getCatalogReason($form, $claim) ?? 0;

        if ($catalogReason > 0) {
            $claim->setCatalogReason($catalogReason); // source unknown
        }
        $claim->setCatalogText($form->getCatalogText() ?? '');

        return $claim;
    }

    private function getCatalogReason(NewClaimFormStruct $form, Claim $claim): ?int
    {
        $reason = $form->getCatalogReason();

        if ($reason === null) {
            return null;
        }

        $claim->setCatalogReason($reason);

        return $claim->getCatalogReason();
    }
}
