<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI;

use stdClass;
use Mefi\Inkasso\Components\SoapAPI\DataTypes\Error;
use Mefi\Inkasso\Components\SoapAPI\DataTypes\ErrorCollection;

abstract class MediafinanzSoapResponse implements ResponseInterface
{
    /** @var stdClass */
    protected $payload;

    /** @var ErrorCollection */
    protected $errors;

    /**
     * @param stdClass $data
     */
    public function __construct($data)
    {
        $this->payload = $data;

        $this->parseErrors();
    }

    public function getData(): stdClass
    {
        return $this->payload;
    }

    public function hasErrors(): bool
    {
        return $this->errors !== null && $this->errors->count() > 0;
    }

    public function getErrors(): ?ErrorCollection
    {
        return $this->errors;
    }

    public function getHumanReadableErrorList(string $listBullet = ''): ?string
    {
        if ($this->getErrors() === null || !$this->hasErrors()) {
            return null;
        }

        $result = '';

        foreach ($this->getErrors() as $error) {
            $result .= $listBullet . $error->getMessage() . PHP_EOL;
        }

        return $result;
    }

    protected function parseErrors(): void
    {
        if (!property_exists($this->payload, 'errorList')) {
            return;
        }

        $this->errors = new ErrorCollection();

        if (is_string($this->payload->errorList)) {
            $this->errors->add(new Error($this->payload->errorList));

            return;
        }

        foreach ($this->payload->errorList as $error) {
            $this->errors->add(new Error($error));
        }
    }
}
