<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI\Partner;

use Psr\Log\LoggerInterface;
use Mefi\Inkasso\Components\ConfigReader\ConfigReaderInterface;
use Mefi\Inkasso\Components\ConfigReader\Struct\Configuration;
use Mefi\Inkasso\Components\SoapAPI\MediafinanzSoapClient;
use Mefi\Inkasso\Components\SoapAPI\RequestInterface;

class PartnerSoapClient extends MediafinanzSoapClient
{
    public const WSDL_PATH                   = 'partner220.wsdl';
    public const PARTNER_AUTH_APPLICATION_ID = '429';
    public const PARTNER_AUTH_LICENCE_KEY    = 'ce87e3453897f0108b52d533ea970b2c';

    /** @var LoggerInterface */
    private $logger;

    public function __construct(
        ConfigReaderInterface $configReader,
        LoggerInterface $logger
    ) {
        parent::__construct($configReader, $logger);

        $this->logger = $logger;
    }

    public function getWsdlPath(): string
    {
        return self::WSDL_PATH;
    }

    public function sendRequest(RequestInterface $request, string $salesChannelId = null)
    {
        $config = $this->configReader->read($salesChannelId);

        if ($this->soapClient === null) {
            $this->soapClient = $this->getSoapClient();
        }

        $functionName = $request->getFunctionName();
        $requestData  = $request->normalizeRequestData();

        $this->logger->info(sprintf('Sending request to %s::%s', $this->getWsdlPath(), $functionName), [
            'payload' => $requestData,
        ]);

        $auth = [
            'applicationId' => self::PARTNER_AUTH_APPLICATION_ID,
            'licenceKey'    => self::PARTNER_AUTH_LICENCE_KEY,
            'sandbox'       => $config->get(Configuration::CONFIG_SANDBOX_ACTIVE, false),
        ];

        $response = $this->soapClient->$functionName($auth, ...$requestData);

        $this->logger->info(sprintf('Received response from %s::%s', $this->getWsdlPath(), $functionName), [
            'payload' => $response,
        ]);

        return $response;
    }
}
