<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\SoapAPI\Partner\Validation;

use Shopware\Core\Framework\Validation\DataBag\RequestDataBag;

class RegistrationValidator implements RegistrationValidatorInterface
{
    public const REQUIRED_REGISTRATION_FIELDS = ['salutation', 'firstname', 'lastname', 'legalForm', 'address', 'zip', 'city', 'country', 'phone', 'mail', 'company'];

    /**
     * {@inheritdoc}
     */
    public function validate(RequestDataBag $requestDataBag): string
    {
        foreach (self::REQUIRED_REGISTRATION_FIELDS as $requiredField) {
            if (!$requestDataBag->has($requiredField) || empty($requestDataBag->get($requiredField, ''))) {
                return $requiredField;
            }
        }

        if (!$this->isMailValid((string) $requestDataBag->get('mail', ''))) {
            return 'mail';
        }

        return '';
    }

    private function isMailValid(string $mail): bool
    {
        return (bool) preg_match('/[^@]+@.+\.[^.]+/', $mail);
    }
}
