<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Solvency;

use Mefi\Inkasso\Components\Solvency\Struct\CustomerInfoStruct;
use Shopware\Core\Checkout\Order\OrderEntity;
use Shopware\Core\Framework\Context;
use Mefi\Inkasso\Components\ConfigReader\ConfigReader;
use Mefi\Inkasso\Components\ConfigReader\Struct\Configuration;
use Mefi\Inkasso\Components\Solvency\Struct\ScoreResult;
use Mefi\Inkasso\Components\SoapAPI\Buergel\Request\Struct\ConCheckScoreRequestStruct;

class OrderSolvencyService implements OrderSolvencyServiceInterface
{
    /** @var ConfigReader */
    private $configReader;

    /** @var SolvencyScoreAdapter */
    private $solvencyScoreAdapter;

    public function __construct(
        ConfigReader $configReader,
        SolvencyScoreAdapter $solvencyScoreAdapter
    ) {
        $this->configReader         = $configReader;
        $this->solvencyScoreAdapter = $solvencyScoreAdapter;
    }

    public function getScoreFromOrder(CustomerInfoStruct $customerInfoStruct, OrderEntity $order, Context $context): ScoreResult
    {

        $pluginConfig = $this->configReader->read($order->getSalesChannelId());

        $address = $customerInfoStruct->getAddress();
        $isB2bCustomer   = !empty($address->getCompany());
        $selectedProduct = $isB2bCustomer ? $pluginConfig->get(Configuration::CONFIG_B2B_PRODUCT, null) : $pluginConfig->get(Configuration::CONFIG_B2C_PRODUCT, null);

        return $this->solvencyScoreAdapter->fetchScore(
            $customerInfoStruct,
            $selectedProduct,
            $order->getAmountTotal(),
            $order->getSalesChannelId(),
            ConCheckScoreRequestStruct::JUSTIFICATION_SOLVENCY_CHECK,
            $context
        );
    }
}
