<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Solvency\Product\Factory;

use RuntimeException;
use Mefi\Inkasso\Components\Solvency\Product\SolvencyProductInterface;

class SolvencyProductFactory implements SolvencyProductFactoryInterface
{
    /** @var iterable|SolvencyProductInterface[] */
    protected $abstractProductCollection = [];

    public function __construct(iterable $abstractProductCollection)
    {
        $this->abstractProductCollection = $abstractProductCollection;
    }

    public function getProduct(string $productName): SolvencyProductInterface
    {
        foreach ($this->abstractProductCollection as $product) {
            if ($product->getProductName() === $productName) {
                return $product;
            }
        }

        throw new RuntimeException(sprintf('mediafinanz solvency check: product %s could not be found!', $productName));
    }
}
