<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Solvency;

use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepositoryInterface;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\EqualsFilter;
use Shopware\Core\Framework\Plugin\Exception\PluginNotFoundException;
use Shopware\Core\Framework\Plugin\PluginEntity;

class ReferenceProvider implements ReferenceProviderInterface
{
    private const REFERENCE_PATTERN = '[#Shopware %s::Plugin %s#]';
    private const PLUGIN_NAME       = 'MefiInkasso';

    /** @var string */
    private $shopwareVersion;

    /** @var EntityRepositoryInterface */
    private $pluginRepository;

    public function __construct(string $shopwareVersion, EntityRepositoryInterface $pluginRepository)
    {
        $this->shopwareVersion  = $shopwareVersion;
        $this->pluginRepository = $pluginRepository;
    }

    /**
     * {@inheritdoc}
     */
    public function getReference(Context $context): string
    {
        $pluginEntity = $this->getPluginEntity($context);

        if ($pluginEntity === null) {
            throw new PluginNotFoundException(self::PLUGIN_NAME);
        }

        return sprintf(self::REFERENCE_PATTERN, $this->shopwareVersion, $pluginEntity->getVersion());
    }

    private function getPluginEntity(Context $context): ?PluginEntity
    {
        $criteria = new Criteria();
        $criteria->addFilter(
            new EqualsFilter('name', self::PLUGIN_NAME)
        );

        return $this->pluginRepository->search($criteria, $context)->first();
    }
}
