<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Solvency\Rule;

use Mefi\Inkasso\Components\ConfigReader\ConfigReaderInterface;
use Mefi\Inkasso\Components\ConfigReader\Struct\Configuration;
use Mefi\Inkasso\Components\Solvency\Struct\ScoringRule;

class ScoringRuleProvider implements ScoringRuleProviderInterface
{
    /** @var ConfigReaderInterface */
    private $pluginConfigReader;

    public function __construct(ConfigReaderInterface $pluginConfigReader)
    {
        $this->pluginConfigReader = $pluginConfigReader;
    }

    public function getB2cRule(float $price, string $salesChannelId = null): ScoringRule
    {
        $config = $this->pluginConfigReader->read($salesChannelId);
        $rules  = $config->get(Configuration::CONFIG_B2C_SCORING);

        return $this->getRule($rules, $price);
    }

    public function getB2bRule(float $price, string $salesChannelId = null): ScoringRule
    {
        $config = $this->pluginConfigReader->read($salesChannelId);
        $rules  = $config->get(Configuration::CONFIG_B2B_SCORING);

        return $this->getRule($rules, $price);
    }

    private function between(?float $min, ?float $max, float $value): bool
    {
        return $min < $value && $max > $value;
    }

    private function getRule(array $rules, float $price): ScoringRule
    {
        $fallbackRule = new ScoringRule();

        foreach ($rules as $rule) {
            $minAmount = (float) $rule['minAmount'];
            $maxAmount = (float) $rule['maxAmount'];
            $score     = (float) $rule['score'];

            if ($this->between($minAmount, $maxAmount, $price)) {
                return new ScoringRule($minAmount, $maxAmount, $score);
            }

            if ($maxAmount <= 0) {
                $fallbackRule = new ScoringRule($maxAmount, $minAmount, $score);
            }
        }

        return $fallbackRule;
    }
}
