<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Solvency\Struct;

use Shopware\Core\Checkout\Order\Aggregate\OrderAddress\OrderAddressEntity;
use Shopware\Core\Checkout\Customer\CustomerEntity;
use Shopware\Core\Framework\Struct\Struct;

class CustomerInfoStruct extends Struct
{
    /** @var OrderAddressEntity */
    protected $address;

    /** @var string */
    protected $email;

    /** @var bool */
    protected $isB2bCustomer;

    /** @var string */
    protected $customerId;

    /** @var string */
    protected $customerNumber;

    /** @var null|string */
    protected $languageId;

    public function __construct(OrderAddressEntity $address, CustomerEntity $customer)
    {
        $this->setAddress($address);
        $this->email      = $customer->getEmail();
        $this->customerId = $customer->getId();
        $this->customerNumber = $customer->getCustomerNumber();
        $this->languageId = $customer->getLanguageId();
    }

    public function getAddress(): OrderAddressEntity
    {
        return $this->address;
    }

    public function setAddress(OrderAddressEntity $address): self
    {
        $address->assign($this->stripWhitespacesFromAddress($address));
        $this->address = $address;

        return $this;
    }

    public function getEmail(): string
    {
        return $this->email;
    }

    public function setEmail(string $email): self
    {
        $this->email = $email;

        return $this;
    }

    public function isB2bCustomer(): bool
    {
        return !empty($this->address->getCompany());
    }

    public function getCustomerId(): string
    {
        return $this->customerId;
    }

    public function setCustomerId(string $customerId): self
    {
        $this->customerId = $customerId;

        return $this;
    }

    public function getLanguageId(): ?string
    {
        return $this->languageId;
    }

    public function setLanguageId(?string $languageId): self
    {
        $this->languageId = $languageId;

        return $this;
    }

    public function getCustomerNumber(): string
    {
        return $this->customerNumber;
    }

    public function setCustomerNumber(string $customerNumber): self
    {
        $this->customerNumber = $customerNumber;

        return $this;
    }

    private function stripWhitespacesFromAddress(OrderAddressEntity $address): array
    {
        return
            [
                'street' => $address->getStreet() ? trim($address->getStreet()) : '',
                'zipcode' => $address->getZipcode() ? trim($address->getZipcode()) : '',
                'city' => $address->getCity() ? trim($address->getCity()) : '',
                'company' => $address->getCompany() ? trim($address->getCompany()) : '',
                'firstName' => $address->getFirstName() ? trim($address->getFirstName()) : '',
                'lastName' => $address->getLastName() ? trim($address->getLastName()) : ''
            ];
    }
}
