<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Components\Solvency\Validation\Constraint;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;

class SolvencyCheckboxValidator extends ConstraintValidator
{
    /**
     * {@inheritdoc}
     */
    public function validate($value, Constraint $constraint): void
    {
        if (!$constraint instanceof SolvencyCheckbox) {
            throw new UnexpectedTypeException($constraint, SolvencyCheckbox::class);
        }

        if ($constraint->allowNull && null === $value) {
            return;
        }

        if (\is_string($value) && null !== $constraint->normalizer) {
            $value = ($constraint->normalizer)($value);
        }

        if (false === $value || (empty($value) && '0' != $value)) {
            $this->context->buildViolation($constraint->message)
                ->setParameter('{{ value }}', $this->formatValue($value))
                ->setCode(SolvencyCheckbox::IS_SOLVENCY_BLANK_ERROR)
                ->addViolation();
        }
    }
}
