<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\DataAbstractionLayer\Claim;

use Shopware\Core\Checkout\Customer\CustomerDefinition;
use Shopware\Core\Checkout\Order\OrderDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToManyAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Mefi\Inkasso\Core\DataAbstractionLayer\ClaimCustomer\ClaimCustomerDefinition;
use Mefi\Inkasso\Core\DataAbstractionLayer\ClaimDetails\ClaimDetailsDefinition;
use Mefi\Inkasso\Core\DataAbstractionLayer\ClaimStatusHistory\ClaimStatusHistoryDefinition;
use Mefi\Inkasso\Core\DataAbstractionLayer\ClaimDirectPayment\ClaimDirectPaymentDefinition;


class ClaimDefinition extends EntityDefinition
{
    public const ENTITY_NAME = 'mefi_inkasso_claim';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return ClaimEntity::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
            (new FkField('customer_id', 'customerId', CustomerDefinition::class, 'id'))->addFlags(new Required()),
            (new FkField('order_id', 'orderId', OrderDefinition::class, 'id'))->addFlags(new Required()),
            (new StringField('invoice_number', 'invoiceNumber'))->addFlags(new Required()),
            (new StringField('file_number', 'fileNumber'))->addFlags(new Required()),
            (new FkField('claim_customer_id', 'claimCustomerId', ClaimCustomerDefinition::class, 'id'))->addFlags(new Required()),
            (new FkField('claim_detail_id', 'claimDetailId', ClaimDetailsDefinition::class, 'id'))->addFlags(new Required()),
            (new CreatedAtField()),
            (new UpdatedAtField()),

            new OneToOneAssociationField('customer', 'customer_id', 'id', CustomerDefinition::class, false),
            new OneToOneAssociationField('order', 'order_id', 'id', OrderDefinition::class, false),
            new OneToOneAssociationField('claimCustomer', 'claim_customer_id', 'id', ClaimCustomerDefinition::class, false),
            new OneToOneAssociationField('claimDetail', 'claim_detail_id', 'id', ClaimDetailsDefinition::class, false),
            new OneToManyAssociationField('statusHistory', ClaimStatusHistoryDefinition::class, 'claim_id', 'id'),
            new OneToManyAssociationField('directPayment', ClaimDirectPaymentDefinition::class, 'claim_id', 'id'),

        ]);
    }
}
