<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\DataAbstractionLayer\ClaimCustomer;

use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Shopware\Core\System\Country\CountryDefinition;
use Mefi\Inkasso\Core\DataAbstractionLayer\Claim\ClaimDefinition;

class ClaimCustomerDefinition extends EntityDefinition
{
    public const ENTITY_NAME = 'mefi_inkasso_claim_customer';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return ClaimCustomerEntity::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
            (new StringField('company', 'company')),
            (new StringField('last_name', 'lastName'))->addFlags(new Required()),
            (new StringField('first_name', 'firstName'))->addFlags(new Required()),
            (new StringField('street', 'street'))->addFlags(new Required()),
            (new StringField('zip_code', 'zipCode'))->addFlags(new Required()),
            (new StringField('city', 'city'))->addFlags(new Required()),
            (new FkField('country_id', 'countryId', CountryDefinition::class, 'id'))->addFlags(new Required()),
            (new StringField('phone', 'phone')),
            (new StringField('email', 'email'))->addFlags(new Required()),
            (new CreatedAtField()),
            (new UpdatedAtField()),

            new OneToOneAssociationField('claim', 'id', 'claim_customer_id', ClaimDefinition::class, false),
            new OneToOneAssociationField('country', 'country_id', 'id', CountryDefinition::class, false),
        ]);
    }
}
