<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\DataAbstractionLayer\ClaimDetails;

use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\DateField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\DateTimeField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FloatField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Mefi\Inkasso\Core\DataAbstractionLayer\Claim\ClaimDefinition;

class ClaimDetailsDefinition extends EntityDefinition
{
    public const ENTITY_NAME = 'mefi_inkasso_claim_details';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return ClaimDetailsEntity::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
            (new StringField('file_number', 'fileNumber'))->addFlags(new Required()),
            (new DateTimeField('time_of_transmission', 'timeOfTransmission'))->addFlags(new Required()),
            (new FloatField('amount', 'amount'))->addFlags(new Required()),
            (new StringField('status', 'status')),
            (new StringField('type', 'type'))->addFlags(new Required()),
            (new StringField('reason', 'reason'))->addFlags(new Required()),
            (new FloatField('cost', 'cost'))->addFlags(new Required()),
            (new DateField('date_of_last_reminder', 'dateOfLastReminder'))->addFlags(new Required()),
            (new StringField('notice', 'notice')),
            (new CreatedAtField()),
            (new UpdatedAtField()),
            new OneToOneAssociationField('claim', 'id', 'claim_detail_id', ClaimDefinition::class, false),
        ]);
    }
}
