<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\DataAbstractionLayer\ClaimDirectPayment;

use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\DateField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FloatField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Mefi\Inkasso\Core\DataAbstractionLayer\Claim\ClaimDefinition;

class ClaimDirectPaymentDefinition extends EntityDefinition
{
    public const ENTITY_NAME = 'mefi_inkasso_claim_direct_payment';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return ClaimDirectPaymentEntity::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
            (new FkField('claim_id', 'claimId', ClaimDefinition::class, 'id'))->addFlags(new Required()),
            (new StringField('invoice_number', 'invoiceNumber')),
            (new StringField('file_number', 'fileNumber'))->addFlags(new Required()),
            (new FloatField('paid_amount', 'paidAmount'))->addFlags(new Required()),
            (new DateField('date_of_payment', 'dateOfPayment'))->addFlags(new Required()),
            (new CreatedAtField()),
            (new UpdatedAtField()),

            (new ManyToOneAssociationField('claim', 'claim_id', ClaimDefinition::class, 'id', false)),
        ]);
    }
}
