<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\DataAbstractionLayer\ClaimStatusHistory;

use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IntField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Mefi\Inkasso\Core\DataAbstractionLayer\Claim\ClaimDefinition;

class ClaimStatusHistoryDefinition extends EntityDefinition
{
    public const ENTITY_NAME = 'mefi_inkasso_claim_status_history';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return ClaimStatusHistoryEntity::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection(
            [
                (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),
                (new FkField('claim_id', 'claimId', ClaimDefinition::class, 'id'))->addFlags(new Required()),
                (new StringField('invoice_number', 'invoiceNumber'))->addFlags(new Required()),
                (new StringField('file_number', 'fileNumber'))->addFlags(new Required()),
                (new StringField('changed_at', 'changedAt'))->addFlags(new Required()),
                (new IntField('status_code', 'statusCode'))->addFlags(new Required()),
                (new StringField('status_name', 'statusName')),
                (new IntField('closing_reason_code', 'closingReasonCode')),
                (new StringField('closing_reason_explanation', 'closingReasonExplanation')),
                (new StringField('closing_reason_note', 'closingReasonNote')),
                (new ManyToOneAssociationField('claim', 'claim_id', ClaimDefinition::class, 'id', false)),
            ]
        );
    }
}
