<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\DataAbstractionLayer\SolvencyCheckHistory;

use Shopware\Core\Checkout\Customer\CustomerDefinition;
use Shopware\Core\Framework\Api\Context\SalesChannelApiSource;
use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\CreatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\ReadProtected;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FloatField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\LongTextField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\StringField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\UpdatedAtField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IntField;

class SolvencyCheckHistoryDefinition extends EntityDefinition
{
    public const ENTITY_NAME = 'mefi_inkasso_solvency_check_history';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getCollectionClass(): string
    {
        return SolvencyCheckHistoryCollection::class;
    }

    public function getEntityClass(): string
    {
        return SolvencyCheckHistoryEntity::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new PrimaryKey(), new Required()),
            (new FkField('customer_id', 'customerId', CustomerDefinition::class))->addFlags(new Required()),
           // (new FkField('order_address_id', 'orderAddressId', OrderAddressDefinition::class))->addFlags(new Required()),
            (new StringField('customernumber', 'customernumber')),
            (new StringField('lastname', 'lastname')),
            (new StringField('firstname', 'firstname')),
            (new StringField('company', 'company')),
            (new StringField('street', 'street')),
            (new StringField('postcode', 'postcode')),
            (new StringField('city', 'city')),
            (new StringField('country', 'country')),
            (new StringField('address_hash', 'addressHash'))->addFlags(new Required()),
            (new FloatField('amount', 'amount'))->addFlags(new Required()),
            (new StringField('product', 'product'))->addFlags(new Required()),
            (new FloatField('score', 'score'))->addFlags(new Required()),
            (new LongTextField('response_text', 'responseText')),
            (new IntField('justification', 'justification')),
            (new CreatedAtField()),
            (new UpdatedAtField()),

       /*     (new ManyToOneAssociationField('customer', 'customer_id', CustomerDefinition::class, 'id', false))
               ->addFlags(new ReadProtected(SalesChannelApiSource::class)),*/
        ]);
    }
}
