<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\Logger;

use Doctrine\DBAL\Connection;
use Monolog\Handler\RotatingFileHandler;
use Monolog\Logger;
use Monolog\Processor\PsrLogMessageProcessor;
use Psr\Log\LoggerInterface;
use Shopware\Core\Framework\Log\Monolog\DoctrineSQLHandler;
use Mefi\Inkasso\Components\ConfigReader\ConfigReaderInterface;
use Mefi\Inkasso\Components\ConfigReader\Struct\Configuration;
use Mefi\Inkasso\Core\Logger\Processor\PseudonymizeProcessor;

class LoggerFactory implements LoggerFactoryInterface
{
    /** @var string */
    protected $rotatingFilePathPattern = '';

    /** @var int */
    protected $logLevel = Logger::ERROR;

    /** @var Connection */
    protected $connection;

    public function __construct(string $rotatingFilePathPattern, Connection $connection)
    {
        $this->rotatingFilePathPattern = $rotatingFilePathPattern;
        $this->connection              = $connection;
    }

    public function setLogLevel(ConfigReaderInterface $configReader): void
    {
        $pluginConfig = $configReader->read();

        if ($pluginConfig->get(Configuration::CONFIG_EXTENDED_LOGGING, false)) {
            $this->logLevel = Logger::DEBUG;
        }
    }

    public function createLogger(string $filePrefix, ?int $fileRotationCount = null): LoggerInterface
    {
        $filepath = sprintf($this->rotatingFilePathPattern, $filePrefix);

        $result = new Logger($filePrefix);
        $result->pushHandler((new RotatingFileHandler($filepath, $fileRotationCount ?? 14, $this->logLevel)));
        $result->pushHandler(new DoctrineSQLHandler($this->connection, Logger::DEBUG));

        $result->pushProcessor(new PseudonymizeProcessor());
        $result->pushProcessor(new PsrLogMessageProcessor());

        return $result;
    }
}
