<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Core\Logger\Processor;

use Monolog\Processor\ProcessorInterface;

class PseudonymizeProcessor implements ProcessorInterface
{
    public const ALLOWED_KEYS = ['city', 'score', 'scoreText', 'requestNumber', 'countOfNegativeEntries', 'countOfRelatedCompanies'];

    public function __invoke(array $record): array
    {
        $encodedRecord = json_encode($record);

        if (!$encodedRecord) {
            return $record;
        }

        return $this->pseudonymizeGeneralClientData(json_decode($encodedRecord, true));
    }

    private function pseudonymizeGeneralClientData(array $record): array
    {
        if (empty($record['context'])) {
            return $record;
        }

        $record['context'] = $this->pseudonymizeBuyer($record['context']);

        return $record;
    }

    private function pseudonymizeBuyer(array $payload): array
    {
        foreach ($payload as &$payloadEntry) {
            $newEntry = [];

            if (is_array($payloadEntry)) {
                foreach (self::ALLOWED_KEYS as $allowedKey) {
                    if (!array_key_exists($allowedKey, $payloadEntry)) {
                        continue;
                    }

                    $newEntry[$allowedKey] = $payloadEntry[$allowedKey];
                }
            }

            if (empty($newEntry) && is_array($payloadEntry)) {
                $newEntry = $this->pseudonymizeBuyer($payloadEntry);
            }

            if (!empty($newEntry)) {
                $payloadEntry = $newEntry;
            }
        }

        unset($payloadEntry);

        return $payload;
    }
}
