const { Application } = Shopware;
const ApiService = Shopware.Classes.ApiService;

class MefiInkassoClaimService extends ApiService {
    constructor(httpClient, loginService, apiEndpoint = 'mediafinanz-claim') {
        super(httpClient, loginService, apiEndpoint);
    }

    /**
     * @return {Promise<AxiosResponse<T>>}
     */
    newClaim(formData) {
        const apiRoute = `_action/${this.getApiBasePath()}/new-claim`;

        return this.httpClient
            .post(
                apiRoute,
                formData,
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    /**
     * @return {Promise<AxiosResponse<T>>}
     */
    closeClaim(fileNumber) {
        const apiRoute = `_action/${this.getApiBasePath()}/close-claim`;

        return this.httpClient
            .post(
                apiRoute,
                {
                    fileNumber: fileNumber
                },
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    /**
     * @return {Promise<AxiosResponse<T>>}
     */
    bookDirectPayment(bookDirectPayment, claimEntity) {
        const apiRoute = `_action/${this.getApiBasePath()}/book-direct-payment`;

        return this.httpClient
            .post(
                apiRoute,
                {
                    fileNumber: claimEntity.fileNumber,
                    dateOfPayment: bookDirectPayment.dateOfPayment,
                    paidAmount: bookDirectPayment.paidAmount
                },
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    getClaimStatus(fileNumber) {
        const apiRoute = `_action/${this.getApiBasePath()}/get-claim-status`;

        return this.httpClient
            .post(
                apiRoute,
                {
                    fileNumber: fileNumber
                },
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }
}

Application.addServiceProvider('MefiInkassoClaimService', (container) => {
    const initContainer = Application.getContainer('init');
    return new MefiInkassoClaimService(initContainer.httpClient, container.loginService);
});
