const { Application } = Shopware;
const ApiService = Shopware.Classes.ApiService;

class MefiInkassoConfigService extends ApiService {
    constructor(httpClient, loginService, apiEndpoint = 'mediafinanz-config') {
        super(httpClient, loginService, apiEndpoint);
    }

    testApiCredentials(config) {
        const apiRoute = `_action/${this.getApiBasePath()}/test-connection`;
        return this.httpClient
            .post(
                apiRoute,
                config,
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    syncClaimStatusChanges() {
        const apiRoute = `_action/${this.getApiBasePath()}/sync-claim-status-changes`;

        return this.httpClient
            .post(
                apiRoute,
                null,
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    /**
     * @return {Promise<AxiosResponse<T>>}
     */
    isClientRegistered() {
        const apiRoute = `_action/${this.getApiBasePath()}/client-registered`;

        return this.httpClient
            .get(
                apiRoute,
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    /**
     * @return {Promise<AxiosResponse<T>>}
     */
    registerClient(registrationData) {
        const apiRoute = `_action/${this.getApiBasePath()}/register`;
        return this.httpClient
            .post(
                apiRoute,
                registrationData,
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }

    generateRegistrationKey() {
        const apiRoute = `_action/${this.getApiBasePath()}/generate-registration-key`;

        return this.httpClient
            .post(
                apiRoute,
                null,
                {
                    headers: this.getBasicHeaders()
                }
            )
            .then((response) => {
                return ApiService.handleResponse(response);
            });
    }
}

Application.addServiceProvider('MefiInkassoConfigService', (container) => {
    const initContainer = Application.getContainer('init');
    return new MefiInkassoConfigService(initContainer.httpClient, container.loginService);
});
