import template from './mefi-inkasso-settings-auth.html.twig';

const { Component, Mixin } = Shopware;

Component.register('mefi-inkasso-settings-auth', {
    template,

    mixins: [
        Mixin.getByName('notification'),
        Mixin.getByName('sw-inline-snippet')
    ],

    inject: [
        'MefiInkassoConfigService'
    ],

    data() {
        return {
            salesChannelId: null,
            isLoading: false,
            isTesting: false
        };
    },

    props: {
        config: {},
        fallbackConfig: {},
        isTestSuccessful: false,
        defaultItem: true
    },

    metaInfo() {
        return {
            title: this.$createTitle()
        };
    },

    methods: {
        getTestConfig() {
            const testConfig = {};

            Object.keys(this.config).forEach((key) => {
                testConfig[key] = this.config[key];
                if (!this.config[key]) {
                    testConfig[key] = this.fallbackConfig[key];
                }
            });

            return testConfig;
        },

        onTest() {
            this.isTesting = true;

            const testConfig = this.getTestConfig();
            this.MefiInkassoConfigService.testApiCredentials(testConfig)
                .then((response) => {
                    if (response.success) {
                        this.createNotificationSuccess({
                            title: this.$tc('mefi-configuration.connectionTest.connectionTestTitle'),
                            message: this.$tc('mefi-configuration.connectionTest.connectionSuccessful')
                        });
                        this.isTestSuccessful = true;
                    } else {
                        this.isTestSuccessful = false;
                        const message = this.$t('mefi-configuration.connectionTest.connectionTextError', {
                            detailMessage: response.message
                        });

                        this.createNotificationError({
                            title: this.$tc('mefi-configuration.connectionTest.connectionTestTitle'),
                            message: message
                        });
                    }
                }).catch(() => {
                    this.isTestSuccessful = false;
                    this.createNotificationError({
                        title: this.$tc('mefi-configuration.connectionTest.connectionTestTitle'),
                        message: this.$tc('mefi-configuration.connectionTest.soapErrorReferLog')
                    });
                }).finally(() => {
                    this.isTesting = false;
                });
        }
    }
});
