import template from './mefi-inkasso-settings-rating-grid.html.twig';
import './mefi-inkasso-settings-rating-grid.scss';

Shopware.Component.register('mefi-inkasso-settings-rating-grid', {
    template,

    props: {
        rules: {
            type: Array,
            required: true
        }
    },

    computed: {
        scoringGridColumns() {
            return [
                {
                    property: 'minAmount',
                    label: this.$tc('mefi-configuration.ratingEvaluation.grid.columnMinAmount'),
                    inlineEdit: 'number',
                    allowResize: true
                },
                {
                    property: 'maxAmount',
                    label: this.$tc('mefi-configuration.ratingEvaluation.grid.columnMaxAmount'),
                    inlineEdit: 'number',
                    allowResize: true
                },
                {
                    property: 'score',
                    label: this.$tc('mefi-configuration.ratingEvaluation.grid.columnScore'),
                    inlineEdit: 'number',
                    allowResize: true
                }
            ];
        }
    },

    methods: {
        onAddItemToGrid() {
            if (!this.rules) {
                this.rules = this.fallbackRules;
            }

            const maxStart = 0.0;
            let minStart = 0.0;

            Object.values(this.rules).forEach((item) => {
                if (item.minAmount > maxStart) {
                    minStart = item.maxAmount + 1;
                }
            });

            const newItemId = this.generateInternalItemId();

            this.rules.push({
                id: newItemId,
                minAmount: minStart,
                maxAmount: maxStart,
                score: 3.0
            });
        },

        onDeleteRule(itemIndex) {
            if (!this.rules) {
                this.rules = this.fallbackRules;
            }

            this.rules.splice(itemIndex, 1);
        },

        /**
         * Generates a random string which is being used to identify the item inside the grid.
         *
         * @return {string}
         */
        generateInternalItemId() {
            return Math.random().toString(36).substring(2) + Date.now().toString(36);
        }
    }
});
