import template from './mefi-configuration-tab-auth.html.twig';

const { Component, Mixin } = Shopware;

Component.register('mefi-configuration-tab-auth', {
    template,

    mixins: [
        Mixin.getByName('notification'),
        Mixin.getByName('sw-inline-snippet')
    ],

    inject: [
        'MefiInkassoConfigService'
    ],

    data() {
        return {
            isTesting: false,
            isRequestingRegistrationKey: false,
            registrationKey: null,
        };
    },

    props: {
        fallbackConfig: {},
        config: {},
        isLoading: false,
        isTestSuccessful: false,
    },

    metaInfo() {
        return {
            title: this.$createTitle()
        };
    },

    methods: {
        onGenerateRegistrationKey() {
            this.isRequestingRegistrationKey = true;

            this.MefiInkassoConfigService.generateRegistrationKey().then((response) => {
                if (response.success && response.registrationKey) {
                    this.registrationKey = response.registrationKey;

                    this.createNotificationSuccess({
                        title: this.$tc('global.default.success'),
                        message: this.$tc('mefi-configuration.authentication.generateRegistrationKeySuccessMessage')
                    });
                } else {
                    this.createNotificationError({
                        title: this.$tc('global.default.error'),
                        message: response.message
                    });
                }
            }).catch(() => {
                this.createNotificationError({
                    title: this.$tc('global.default.error'),
                    message: this.$tc('mefi-configuration.authentication.generateRegistrationKeyErrorMessage')
                });
            }).finally(() => {
                this.isRequestingRegistrationKey = false;
            });
        }
    }
});
