import template from './mefi-configuration-tab-rating.html.twig';

Shopware.Component.register('mefi-configuration-tab-rating', {
    template,

    data() {
        return {
            currentLanguageId: '',
            currentNotification: '',
            paymentMethodCollection: []
        };
    },

    inject: ['repositoryFactory'],

    props: {
        fallbackConfig: {},
        config: {},
        isLoading: false,
        swContext: {}
    },

    computed: {
        paymentMethodRepository() {
            return this.repositoryFactory.create('payment_method');
        }
    },

    watch: {
        config: {
            handler() {
                this.getPaymentMethodCollection();
            },
            deep: true,
            immediate: true
        }
    },

    methods: {
        getPaymentMethodCollection() {
            if (this.paymentMethodCollection.length > 0) {
                return;
            }

            this.paymentMethodCollection = new Shopware.Data.EntityCollection(
                this.paymentMethodRepository.route,
                this.paymentMethodRepository.entityName,
                this.swContext
            );

            if (!this.config.checkPaymentMethods || this.config.checkPaymentMethods.length < 1) {
                return;
            }

            const criteria = new Shopware.Data.Criteria();
            criteria.setIds(this.config.checkPaymentMethods);

            this.isLoading = true;

            this.paymentMethodRepository.search(criteria, this.swContext).then((paymentMethods) => {
                this.paymentMethodCollection = paymentMethods;
            }).finally(() => {
                this.isLoading = false;
            });
        },

        setPaymentMethodIds(paymentMethodCollection) {
            this.config.checkPaymentMethods = paymentMethodCollection.getIds();
            this.paymentMethodCollection = paymentMethodCollection;
        },

        onLanguageChange(languageId) {
            if (!this.config.notification) {
                this.config.notification = {};
            }

            if (!this.config.notification[languageId]) {
                this.config.notification[languageId] = '';
            }

            if (this.fallbackConfig.notification && this.fallbackConfig.notification[languageId]
             && this.config.notification[languageId] === '') {
                this.currentNotification = this.fallbackConfig.notification[languageId];

                return;
            }

            if (languageId !== this.currentLanguageId) {
                this.config.notification[this.currentLanguageId] = this.currentNotification;
            }

            this.currentNotification = this.config.notification[languageId];
            this.currentLanguageId = languageId;
        },

        getLanguageFieldPlaceholder() {
            if (!this.fallbackConfig.notification ||
                !this.fallbackConfig.notification[this.currentLanguageId]) {
                return this.$tc('mefi-configuration.rating.notification.notification.placeholder');
            }

            return this.fallbackConfig.notification[this.currentLanguageId];
        },

        onNotificationChange(value) {
            if (!this.config.notification) {
                this.config.notification = {};
            }

            this.config.notification[this.currentLanguageId] = value;
        }
    }
});
