import template from './mefi-configuration-tab-register.html.twig';

Shopware.Component.register('mefi-configuration-tab-register', {
    template,

    mixins: [
        Shopware.Mixin.getByName('notification'),
        Shopware.Mixin.getByName('sw-inline-snippet')
    ],

    inject: [
        'MefiInkassoConfigService'
    ],

    props: {
        isLoading: false
    },

    data() {
        return {
            registrationData: {},
            isRegisterPending: false,
            isRegisterSuccessful: false,
            requiredFields: ['salutation', 'firstname', 'lastname', 'legalForm', 'address', 'zip', 'city', 'country', 'phone', 'mail', 'company']
        };
    },

    computed: {
        legalFormOptions() {
            return [
                { id: 'gbr', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.gbr') },
                { id: 'ohg', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.ohg') },
                { id: 'kg', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.kg') },
                { id: 'ek', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.ek') },
                { id: 'gmbh', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.gmbh') },
                { id: 'gmbh_co_kg', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.gmbh_co_kg') },
                { id: 'ag', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.ag') },
                { id: 'ug', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.ug') },
                { id: 'pic', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.pic') },
                { id: 'ltd', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.ltd') },
                { id: 'freelancer', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.freelancer') },
                { id: 'etc', name: this.$tc('mefi-configuration.register.fields.legalFormOptions.etc') }
            ];
        }
    },

    metaInfo() {
        return {
            title: this.$createTitle()
        };
    },

    methods: {
        onRegister() {
            if (!this.isFormValid()) {
                return;
            }
            this.isRegisterPending = true;

            this.MefiInkassoConfigService.registerClient(this.registrationData)
                .then((response) => {
                    if (response.success === true) {
                        this.createNotificationSuccess({
                            title: this.$tc('global.default.success'),
                            message: this.$tc('mefi-configuration.register.success')
                        });

                        this.isRegisterSuccessful = true;

                        return;
                    } if (response.success === false && response.message) {
                        this.createNotificationError({
                            title: this.$tc('global.default.error'),
                            message: this.$tc('mefi-configuration.register.apiError', 0, {
                                errorMessage: response.message
                            })
                        });

                        return;
                    }

                    this.createNotificationError({
                        title: this.$tc('global.default.error'),
                        message: this.$tc('mefi-configuration.register.missingData')
                    });
                })
                .catch(() => {
                    this.createNotificationError({
                        title: this.$tc('global.default.error'),
                        message: this.$tc('mefi-configuration.register.missingData')
                    });

                    this.isRegisterSuccessful = false;
                })
                .finally(() => {
                    this.isRegisterPending = false;
                });
        },

        isFormValid() {
            let isValid = true;

            this.requiredFields.forEach((fieldName) => {
                if (!this.registrationData) {
                    this.createNotificationError({
                        title: this.$tc('global.default.error'),
                        message: this.$tc('mefi-configuration.register.missingData')
                    });

                    isValid = false;
                    return;
                }

                if (!this.registrationData[fieldName]) {
                    this.createNotificationError({
                        title: this.$tc('global.default.error'),
                        message: this.$tc(
                            'mefi-configuration.register.emptyField',
                            0,
                            {
                                fieldName: this.$tc(`mefi-configuration.register.fields.${fieldName}`)
                            }
                        )
                    });

                    isValid = false;
                }
            });

            return isValid;
        }
    }
});
