import template from './sw-order-detail-base.html.twig';
import './sw-order-detail-base.scss';

const Criteria = Shopware.Data.Criteria;
const { Component, Mixin, Context } = Shopware;

Component.override('sw-order-detail-base', {
    template,

    inject: [
        'repositoryFactory',
        'MefiInkassoClaimService'
    ],

    mixins: [
        Mixin.getByName('notification')
    ],

    data() {
        return {
            claim: null,
            claimStatusHistory: [],
            isLoadingStatusHistory: false,
            isLoadingClaimStatus: false,
            claimStatus: null
        };
    },

    computed: {
        claimRepository() {
            return this.repositoryFactory.create('mefi_inkasso_claim');
        },

        claimStatusHistoryRepository() {
            return this.repositoryFactory.create('mefi_inkasso_claim_status_history');
        },

        claimCriteria() {
            const criteria = new Criteria();

            criteria.addAssociation('claimDetail');
            criteria.addAssociation('claimCustomer');
            criteria.addFilter(Criteria.equals('orderId', this.orderId));

            return criteria;
        },

        claimStatusHistoryCriteria() {
            const criteria = new Criteria();
            criteria.addFilter(Criteria.equals('claimId', this.claim.id));

            return criteria;
        },

        statusGridColumns() {
            return [{
                property: 'id',
                visible: false,
                primary: true
            }, {
                property: 'changedAt',
                label: 'mefi-order.detail.grid.changedAt'
            }, {
                property: 'statusName',
                label: 'mefi-order.detail.grid.statusName',
                allowResize: true
            }, {
                property: 'closingReasonExplanation',
                label: 'mefi-order.detail.grid.closingReason',
                allowResize: true
            }, {
                property: 'closingReasonNote',
                label: 'mefi-order.detail.grid.closingReasonNote',
                allowResize: true
            }];
        },

        closingReason() {
            let result = null;

            this.claimStatusHistory.forEach((item) => {
                if (item.closingReasonCode > 0) {
                    result = {
                        code: item.closingReasonCode,
                        explanation: item.closingReasonExplanation,
                        note: item.closingReasonNote
                    };
                }
            });

            return result;
        }
    },

    created() {
        this.loadClaimDetails();
    },

    methods: {
        loadClaimDetails() {
            this.claimRepository.search(this.claimCriteria, Context.api).then((claimSearchResult) => {
                if (claimSearchResult.first() !== null) {
                    this.claim = claimSearchResult.first();

                    this.loadClaimStatusHistory();
                    this.loadClaimStatus();
                }
            });
        },

        loadClaimStatusHistory() {
            if (!this.claim || !this.claim.fileNumber) {
                return;
            }

            this.isLoadingStatusHistory = true;

            this.claimStatusHistoryRepository.search(this.claimStatusHistoryCriteria, Context.api).then((claimStatusHistorySearchResult) => {
                this.claimStatusHistory = claimStatusHistorySearchResult;

                this.latestStatus = claimStatusHistorySearchResult.last();
            }).finally(() => {
                this.isLoadingStatusHistory = false;
            });
        },

        loadClaimStatus() {
            if (!this.claim || !this.claim.fileNumber) {
                return;
            }

            this.isLoadingClaimStatus = true;

            this.MefiInkassoClaimService.getClaimStatus(this.claim.fileNumber).then((response) => {
                if (response.success) {
                    this.claimStatus = response.status;
                } else {
                    this.createNotificationError({
                        title: this.$tc('mefi-order.detail.errorTitle'),
                        message: response.message
                    });
                }
            }).finally(() => {
                this.isLoadingClaimStatus = false;
            });
        }
    }
});
