import template from './mefi-solvency-detail.html.twig';

const { Component, Mixin } = Shopware;
const Criteria = Shopware.Data.Criteria;

Component.register('mefi-solvency-detail', {
    template,

    mixins: [
        Mixin.getByName('notification')
    ],

    inject: ['repositoryFactory', 'MefiInkassoSolvencyApiService'],

    computed: {
        historyRepository() {
            return this.repositoryFactory.create('mefi_inkasso_solvency_check_history');
        },

        justificationReason() {
            return [
                { id: 1, name: this.$tc('mefi-configuration.justification.reason.credit_request') },
                { id: 2, name: this.$tc('mefi-configuration.justification.reason.business_initiation') },
                { id: 3, name: this.$tc('mefi-configuration.justification.reason.solvency_check') },
                { id: 4, name: this.$tc('mefi-configuration.justification.reason.claim') }
            ];
        },

        productDataSource() {
            return [
                { id: 'buergel_basic', name: this.$tc('mefi-configuration.products.buergel_basic') },
                { id: 'buergel_normal', name: this.$tc('mefi-configuration.products.buergel_normal') },
                { id: 'buergel_plus', name: this.$tc('mefi-configuration.products.buergel_plus') },
                { id: 'risk_normal', name: this.$tc('mefi-configuration.products.risk_normal') },
                { id: 'risk_advanced', name: this.$tc('mefi-configuration.products.risk_advanced') },
                { id: 'risk_professional', name: this.$tc('mefi-configuration.products.risk_professional') }
            ];
        }
    },

    props: {
        notify: {
            type: Boolean,
            required: false
        }
    },

    data() {
        return {
            isLoading: false,
            scoreError: null,
            solvencyHistory: {}
        };
    },

    created() {
        this.loadHistoryData();
    },

    methods: {
        loadHistoryData() {
            this.solvencyProducts = this.productDataSource;
            this.solvencyJustification = this.justificationReason;

            if (!this.$route.params.historyId) {
                return;
            }
            this.historyId = this.$route.params.historyId;
            this.notify = !this.$route.params.notify ? false : this.$route.params.notify;
            this.isLoading = true;

            const criteria = new Criteria();

            this.historyRepository.get(this.historyId, Shopware.Context.api, criteria)
                .then((solvencyHistory) => {
                    this.solvencyHistory = solvencyHistory;
                    this.isLoading = false;
                });
        }
    }
});
