import template from './mefi-solvency-list.html.twig';
import './mefi-solvency-list.scss';

const { Component, Mixin } = Shopware;
const Criteria = Shopware.Data.Criteria;

Component.register('mefi-solvency-list', {
    template,

    mixins: [
        Mixin.getByName('listing'),
        Mixin.getByName('notification')
    ],

    inject: ['repositoryFactory', 'MefiInkassoSolvencyApiService'],

    computed: {
        historyRepository() {
            return this.repositoryFactory.create('mefi_inkasso_solvency_check_history');
        },
        solvencyHistoryColumns() {
            return [
                {property: 'customernumber', label: this.$tc('mefi-solvency-history.list.label.customernumber')},
                {property: 'company', label: this.$tc('mefi-solvency-history.list.label.company')},
                {property: 'firstname', label: this.$tc('mefi-solvency-history.list.label.person')},
                {property: 'street', label: this.$tc('mefi-solvency-history.list.label.address')},
                {property: 'score', label: this.$tc('mefi-solvency-history.list.label.score')},
                {property: 'responseText', label: this.$tc('mefi-solvency-history.list.label.responseText')},
                {property: 'product', label: this.$tc('mefi-solvency-history.list.label.product'), visible: false},
                {property: 'amount', label: this.$tc('mefi-solvency-history.list.label.amount'), visible: false},
                {property: 'createdAt', label: this.$tc('mefi-solvency-history.list.label.created')},
                {property: 'updatedAt', label: this.$tc('mefi-solvency-history.list.label.updated'), visible: false}
            ]
        }
    },

    data() {
        return {
            solvencyChecks: null,
            limit: 25,
            isLoading: false,
            sortBy: 'createdAt',
            sortDirection: 'DESC',
            filterLoading: false
        };
    },

    methods: {

        getList() {
            this.isLoading = true;

            const solvencyHistoryCriteria = new Criteria(this.page, this.limit);

            return this.historyRepository.search(solvencyHistoryCriteria, Shopware.Context.api)
                .then((result) => {
                    this.solvencyChecks = result;
                    this.total = result.total;
                    this.page = result.criteria.page;
                    this.limit = result.criteria.limit;
                }).finally(() => {
                this.isLoading = false;
            });
        },
    }
});

