<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Utils;

use Shopware\Core\Checkout\Cart\Order\Transformer\AddressTransformer;
use Shopware\Core\Checkout\Customer\Aggregate\CustomerAddress\CustomerAddressEntity;
use Shopware\Core\Checkout\Customer\Exception\AddressNotFoundException;
use Shopware\Core\Checkout\Order\Aggregate\OrderAddress\OrderAddressEntity;
use Shopware\Core\Checkout\Order\OrderEntity;

class AddressHelper
{
    public static function getBillingAddressFromOrder(OrderEntity $order): OrderAddressEntity
    {
        $addresses = $order->getAddresses();

        if ($addresses === null || $addresses->get($order->getBillingAddressId()) === null) {
            throw new AddressNotFoundException($order->getBillingAddressId());
        }

        return $addresses->get($order->getBillingAddressId());
    }

    public static function getShippingAddressFromOrder(OrderEntity $order): ?OrderAddressEntity
    {
        $deliveries = $order->getDeliveries();
        $delivery   = $deliveries ? $deliveries->first() : null;

        return $delivery ? $delivery->getShippingOrderAddress() : null;
    }

    public static function createOrderAddressByAddress(CustomerAddressEntity $address): ?OrderAddressEntity
    {
        $orderAddress = new OrderAddressEntity();
        $orderAddress->assign(AddressTransformer::transform($address));
      //  $orderAddress->assign(array_map('trim',AddressTransformer::transform($address)));

        return $orderAddress;
    }

    public static function equals(OrderAddressEntity $addressA, OrderAddressEntity $addressB): bool
    {
        $addressStringA = self::getAddressString($addressA);
        $addressStringB = self::getAddressString($addressB);

        $addressStringA = filter_var($addressStringA, FILTER_SANITIZE_SPECIAL_CHARS);
        $addressStringB = filter_var($addressStringB, FILTER_SANITIZE_SPECIAL_CHARS);

        return $addressStringA === $addressStringB;
    }

    public static function getHashFromAddress(OrderAddressEntity $address): string
    {
        return sha1(self::getAddressString($address));
    }

    private static function getAddressString(OrderAddressEntity $address): string
    {
        return preg_replace(
            '/[^\pL\p{Nd}]/u',
            '',
            strtolower (
                $address->getStreet() .
                $address->getZipcode() .
                $address->getCity() .
                $address->getCompany() .
                $address->getFirstName() .
                $address->getLastName()
            )
        );
    }
}
