<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Utils\Connection\Struct;

use Shopware\Core\Framework\Struct\Struct;

class ValidationResult extends Struct
{
    /** @var bool */
    protected $success;

    /** @var null|string */
    protected $message;

    /** @var array */
    protected $claimList;

    /**
     * ValidationResult constructor.
     * @param bool $success
     * @param string|null $message
     * @param array $claimList
     */
    public function __construct(bool $success, string $message = null, array $claimList = array() )
    {
        $this->success = $success;
        $this->message = $message;
        $this->claimList = $claimList;
    }

    /**
     * @return bool
     */
    public function isSuccess(): bool
    {
        return $this->success;
    }

    /**
     * @return string|null
     */
    public function getMessage(): ?string
    {
        return $this->message;
    }

    /**
     * @return array
     */
    public function getClaimList(): array
    {
        return $this->claimList;
    }
}
