<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Utils;

use Composer\Autoload\ClassLoader;

final class MefiInkassoClassLoader extends ClassLoader
{
    private const VENDOR_DEPENDENCIES_PSR4 = [
        'VIISON\\AddressSplitter\\' => 'viison/address-splitter/src/',
    ];

    public function __construct()
    {
        parent::__construct();
        $this->addPsr4Dependencies();
    }

    /**
     * Iterates over self::VENDOR_DEPENDENCIES_PSR4 to register available namespaces.
     */
    private function addPsr4Dependencies(): void
    {
        $vendorDir = __DIR__ . '/../../vendor/';

        foreach (self::VENDOR_DEPENDENCIES_PSR4 as $prefix => $relativePath) {
            $path = $vendorDir . $relativePath;

            if (!file_exists($path)) {
                continue;
            }

            $this->addPsr4($prefix, $path);
        }
    }
}
