<?php

declare(strict_types=1);

namespace Mefi\Inkasso\Utils;

use Psr\Log\LoggerInterface;
use Shopware\Core\Checkout\Customer\Aggregate\CustomerAddress\CustomerAddressEntity;
use Shopware\Core\Checkout\Customer\CustomerEntity;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Mefi\Inkasso\Components\Solvency\EventListeners\SolvencyScoreEventListener;

class SalesChannelHelper
{
    public static function isCountryAllowedForSolvencyChecks(SalesChannelContext $context, LoggerInterface $logger): bool
    {

        $customer = $context->getCustomer();

        if ($customer === null) {
            return false;
        }

        $billingAddress = $customer->getDefaultBillingAddress();

        if ($billingAddress === null) {

            $logger->debug(__METHOD__ . ":\tinvalid billing address");
            return false;
        }

        $country = $billingAddress->getCountry();

        if ($country === null) {
            $logger->debug(__METHOD__ . ":\tinvalid country object");
            return false;
        }

        if (!in_array($country->getIso(), SolvencyScoreEventListener::ALLOWED_COUNTRIES, true)) {
            $logger->debug(__METHOD__ . ":\tcountry not allowed", [
                'countryIso' => $country->getIso()
            ]);
            return false;
        }

        return true;
    }

    public static function getCustomerForSolvencyChecks(SalesChannelContext $context): CustomerEntity {
        return $context->getCustomer();
    }

   public static function getBillingAddressForSolvencyChecks(CustomerEntity $customer): CustomerAddressEntity {
        return $customer->getActiveBillingAddress();
    }

}
